![mooda header](docs/img/logos/mooda_gui-documentation-header.png)

Mooda_gui is a Graphical User Interface that allows using some of the functionalities of [mooda](https://github.com/rbardaji/mooda).

The GUI is written with pyQT but it designed for non-python users.

![mooda_screenshot](docs/img/readme/screenshot.PNG)

# Where to get it

Binary installers for the latest released stable version are available at the [Python package index](https://pypi.org/project/mooda_gui/)

```cmd
pip install mooda_gui
```

See more [instructions](docs/installation/installation.md) for installation from sources or non-PyPi releases.

# Run it

Just write:

```bash
python -m mooda_gui
```

# License

[MIT](LICENSE)

# Documentation

The official documentation is hosted here, on the [docs directory](docs/index_docs.md).